summaryrefslogtreecommitdiffstats
path: root/konversation/src/nickinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/nickinfo.h')
-rw-r--r--konversation/src/nickinfo.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/konversation/src/nickinfo.h b/konversation/src/nickinfo.h
index 29bf006..9167b6f 100644
--- a/konversation/src/nickinfo.h
+++ b/konversation/src/nickinfo.h
@@ -33,7 +33,7 @@ class TQTimer;
Offline (but watched or in addressbook) nicks are stored in the Server object.
*/
-class NickInfo : public TQObject, public KShared
+class NickInfo : public TQObject, public TDEShared
{
Q_OBJECT
@@ -174,10 +174,10 @@ class NickInfo : public TQObject, public KShared
void nickInfoChanged(void);
};
/** A NickInfoPtr is a pointer to a NickInfo object. Since it is a KSharedPtr, the NickInfo
* object is automatically destroyed when all references are destroyed.
*/
-typedef KSharedPtr<NickInfo> NickInfoPtr;
+typedef TDESharedPtr<NickInfo> NickInfoPtr;
/** A NickInfoMap is a list of NickInfo objects, indexed and sorted by lowercase nickname.
*/
typedef TQMap<TQString,NickInfoPtr> NickInfoMap;
@@ -174,10 +174,10 @@ class NickInfo : public TQObject, public KShared
void nickInfoChanged(void);
};
-/** A NickInfoPtr is a pointer to a NickInfo object. Since it is a KSharedPtr, the NickInfo
+/** A NickInfoPtr is a pointer to a NickInfo object. Since it is a TDESharedPtr, the NickInfo
* object is automatically destroyed when all references are destroyed.
*/